@@ -33,7 +33,6 @@ sub new {
     	}
 	$self->resource_name = "$env->{SCRIPT_NAME}$env->{PATH_INFO}"
 		  . ($env->{QUERY_STRING} ? "?$env->{QUERY_STRING}" : "");
-	$self->body = "";
 	$self->psgix = $env->{'psgix.io'}; 
 	if ($env->{HTTP_X_FORWARDED_PROTO} && $env->{HTTP_X_FORWARDED_PROTO} eq 'https') {
 		$self->secure(1);
@@ -94,13 +93,12 @@ sub headers {
 sub send {
 	my ($self, $message) = @_;
 	my $pg = $self->psgix;	
-	my $mask = 1; $self->mask;
+	my $mask = $self->mask ||= 0;
 	my (@DECODED) = map { ord($_) } split //, $message;
-	my @ENCODED;
-	my @MASK;
+	my (@ENCODED, @MASK);
 	my $length = scalar @DECODED + 128;
 	if ($length > 256 || $mask) {
-		@MASK = (1, 1, 1, 1); # map { int(rand(256)) } 0 .. 3;
+		@MASK = map { int(rand(256)) } 0 .. 3;
 		my $i;
 		for (@DECODED) {
 			push @ENCODED, $_ ^ $MASK[$i++ % 4];
@@ -117,9 +115,9 @@ sub send {
 		}
 	} else {
 		@ENCODED = @DECODED;
-		unshift @ENCODED, $length;
+		unshift @ENCODED, $length - 128;
 	}
-	syswrite $pg, join("", map {chr($_)} (128 + ($mask ? 1 : 0),  @ENCODED));
+	syswrite $pg, join("", map {chr($_)} (129,  @ENCODED));
 	return;
 }
 
@@ -164,7 +162,7 @@ Terse::WebSocket - Lightweight WebSockets
 
 =head1 VERSION
 
-Version 0.113
+Version 0.114
 
 =cut
 
