@@ -29,7 +29,7 @@ sub web {
 			$websocket->send('response');
 		},
 		error => sub {
-			$t->logError('Kaput');
+			$t->logError('Kaput' . $_[1]);
 		} 
 	);
 }	
